@@ -1,4 +1,4 @@
 _base_ = [
-    '../_base_/datasets_and_models/datasets.py', '../_base_/datasets_and_models/models.py',
+    '../_base_/datasets/gpt.py', '../_base_/models/gpt.py',
     '../_base_/schedules/default_schedule.py', '../_base_/default_runtime.py'
 ]
