@@ -1,5 +1,4 @@
-from nami.registry import COLLATE
-from nami.registry import TOKENIZERS
+from nami.registry import COLLATE, TOKENIZERS
 
 
 @COLLATE.register_module()
